@@ -73,7 +73,7 @@ class Demo():
         frame = HtmlFrame(root)
 
         frame.on_title_change(self.change_title)
-        frame.load_website("https://wiki.python.org/moin/TkInter")
+        frame.load_html("<mark>dfsdfg</mark>")
 
         frame.pack(expand=True, fill="both")
         root.mainloop()
